Module fmt

Module fmt 

Helper functions and types for formatting.

Structs

Separators
Displays a sequence of elements as comma separated list with a final separator.

Enums

Term
A struct which formats the given value in either singular (1) or plural (2+).

Traits

Plural
Types which affect the plurality of a word. Mostly numbers.