pub struct Expect(/* private fields */);Expand description
Specify what you expect to see after the test concluded.
See TempTestEnv::run.
Implementations
Sourceimpl Expect
impl Expect
Sourcepub fn expect_dir<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
pub fn expect_dir<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
Ensure a directory exists after a test ran.
Sourcepub fn expect_file<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
pub fn expect_file<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
Ensure a file exists after a test ran.
Sourcepub fn expect_file_content<P: AsRef<Path>>(
&mut self,
path: P,
content: impl AsRef<[u8]>,
) -> &mut Self
pub fn expect_file_content<P: AsRef<Path>>( &mut self, path: P, content: impl AsRef<[u8]>, ) -> &mut Self
Ensure a file with the given content exists after a test ran.
Sourcepub fn expect_file_empty<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
pub fn expect_file_empty<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
Ensure an empty file exists after a test ran.