pub struct Setup(/* private fields */);Expand description
Set up the project structure.
Implementations
Sourceimpl Setup
impl Setup
Sourcepub fn setup_dir<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
pub fn setup_dir<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
Create a directory and all its parents within the test root.
May panic if io errros are encountered.
Sourcepub fn setup_file<P: AsRef<Path>>(
&mut self,
path: P,
content: impl AsRef<[u8]>,
) -> &mut Self
pub fn setup_file<P: AsRef<Path>>( &mut self, path: P, content: impl AsRef<[u8]>, ) -> &mut Self
Create a file and all its parent directories within the test root.
May panic if io errros are encountered.
Sourcepub fn setup_file_empty<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
pub fn setup_file_empty<P: AsRef<Path>>(&mut self, path: P) -> &mut Self
Create a directory and all its parents within the test root.
May panic if io errros are encountered.