Struct Separators

pub struct Separators { /* private fields */ }
Displays a sequence of elements as comma separated list with a final separator.

Examples

assert_eq!(
   Separators::new(", ", " or ").with(&["a", "b", "c"]).to_string(),
   "a, b or c",
);
assert_eq!(
   Separators::comma_or().with(&["a", "b", "c"]).to_string(),
   "a, b or c",
);

Implementations

Source

impl Separators

pub fn new( separator: &'static str, terminal_separator: impl Into<Option<&'static str>>, ) -> Self

Creates a new sequence to display.

Examples
assert_eq!(
    Separators::new("-", None).with(["a", "b", "c"]).to_string(),
    "a-b-c",
);
assert_eq!(
    Separators::new("-", "/").with(["a", "b", "c"]).to_string(),
    "a-b/c",
);
pub fn comma() -> Self

Creates a new sequence to display using only , as separator.

Examples
assert_eq!(
   Separators::comma().with(["a", "b"]).to_string(),
   "a, b",
);
assert_eq!(
   Separators::comma().with(["a", "b", "c"]).to_string(),
   "a, b, c",
);
pub fn comma_or() -> Self

Creates a new sequence to display using , and or as the separators.

Examples
assert_eq!(
    Separators::comma_or().with(["a", "b"]).to_string(),
    "a or b",
);
assert_eq!(
    Separators::comma_or().with(["a", "b", "c"]).to_string(),
    "a, b or c",
);
pub fn comma_and() -> Self

Creates a new sequence to display using , and and as the separators.

Examples
assert_eq!(
   Separators::comma_and().with(["a", "b"]).to_string(),
   "a and b",
);
assert_eq!(
   Separators::comma_and().with(["a", "b", "c"]).to_string(),
   "a, b and c",
);
pub fn with<S>(self, items: S) -> impl Display

Formats th given items with this sequence’s separators.

Examples
assert_eq!(
   Separators::new(", ", " or ").with(["a", "b", "c"]).to_string(),
   "a, b or c",
);
assert_eq!(
   Separators::comma_or().with(["a", "b", "c"]).to_string(),
   "a, b or c",
);