Struct TempTestEnv

pub struct TempTestEnv { /* private fields */ }
Creates a temporary test environment in which files and directories can be prepared and checked against after the test ran.

Implementations

Source

impl TempTestEnv

pub fn run( setup: impl FnOnce(&mut Setup) -> &mut Setup, test: impl FnOnce(&Path), expect: impl FnOnce(&mut Expect) -> &mut Expect, )

Create a test enviroment and run the given test in it.

The given closures for setup and expect set up the test environment and configure the expected end state respectively.

pub fn run_no_check( setup: impl FnOnce(&mut Setup) -> &mut Setup, test: impl FnOnce(&Path), )

Create a test enviroment and run the given test in it.

This is the same as TempTestEnv::run, but does not check the resulting directory structure.