Module path

Helper functions and types for paths.

Functions

common_ancestor
Returns the lexical common ancestor of two paths if there is any. This means it will not canonicalize paths.
is_ancestor_of
Returns whether base is an ancestor of path lexically. This means it will not canonicalize paths and may not always be correct (e.g. in the presence of symlinks or filesystem mounts).